_mm256_zeroupper

Function _mm256_zeroupper 

1.27.0 · Source
pub fn _mm256_zeroupper()
Available on target feature avx and (x86 or x86-64) only.
Zeroes the upper 128 bits of all YMM registers; the lower 128-bits of the registers are unmodified.

This operation is purely a performance hint for the CPU and has no effect on the Abstract Machine state.

Intel’s documentation